@@ -27,6 +27,9 @@ import logging
 from . import monitor
 from .link import get_link, is_link_up
 
+NEWLINK_STATE_UP = {'event': 'new_link', 'state': 'up'}
+DELLINK_STATE_DOWN = {'event': 'del_link', 'state': 'down'}
+
 
 @contextmanager
 def waitfor_linkup(iface, oper_blocking=True, timeout=10):
@@ -57,7 +60,7 @@ def waitfor_ipv4_addr(iface, address=None, timeout=10):
     if address:
         expected_event.update(address=address)
     groups = ('ipv4-ifaddr',)
-    with _wait_for_event(iface, expected_event, groups, timeout):
+    with wait_for_event(iface, expected_event, groups, timeout):
         yield
 
 
@@ -74,7 +77,7 @@ def waitfor_ipv6_addr(iface, address=None, timeout=10):
     if address:
         expected_event.update(address=address)
     groups = ('ipv6-ifaddr',)
-    with _wait_for_event(iface, expected_event, groups, timeout):
+    with wait_for_event(iface, expected_event, groups, timeout):
         yield
 
 
@@ -86,19 +89,21 @@ def waitfor_link_exists(iface, timeout=0.5):
     :param timeout: The maximum time in seconds to wait for the message.
     """
     expected_event = {'name': iface, 'event': 'new_link'}
-    with _wait_for_link_event(iface, expected_event, timeout):
+    with wait_for_link_event(iface, expected_event, timeout):
         yield
 
 
 @contextmanager
-def _wait_for_link_event(iface, expected_event, timeout):
+def wait_for_link_event(iface, expected_event, timeout,
+                        check_event=lambda event: True):
     groups = ('link',)
-    with _wait_for_event(iface, expected_event, groups, timeout):
+    with wait_for_event(iface, expected_event, groups, timeout, check_event):
         yield
 
 
 @contextmanager
-def _wait_for_event(iface, expected_event, groups, timeout):
+def wait_for_event(iface, expected_event, groups, timeout,
+                   check_event=lambda event: True):
     with monitor.Monitor(groups=groups, timeout=timeout) as mon:
         try:
             yield
@@ -107,7 +112,8 @@ def _wait_for_event(iface, expected_event, groups, timeout):
             try:
                 for event in mon:
                     caught_events.append(event)
-                    if _is_subdict(expected_event, event):
+                    if _is_subdict(expected_event, event) and check_event(
+                            event):
                         return
             except monitor.MonitorError as e:
                 if e.args[0] == monitor.E_TIMEOUT:
