@@ -16,16 +16,13 @@ export \
     LC_ALL=C \
     NOSE_EVAL_ATTR \
     NOSE_LOGFORMAT='%(asctime)s %(levelname)-5s (%(threadName)s) [%(name)s] %(message)s (%(module)s:%(lineno)d)' \
-    NOSE_VERBOSE=${NOSE_VERBOSE:-3} \
+    NOSE_VERBOSE=${NOSE_VERBOSE:-1} \
     PYTHONDONTWRITEBYTECODE=1 \
     PYTHONPATH="../static/usr/share/vdsm:../lib:../vdsm_api:$PYTHONPATH" \
     $NULL
 
-"$PYTHON_EXE" ../tests/testrunner.py --local-modules $@ &
-runner_pid=$!
-
 if [ -n "$TIMEOUT" ]; then
-    ./py-watch $runner_pid $TIMEOUT &
+    PYTHON_EXE="./py-watch $TIMEOUT $PYTHON_EXE"
 fi
 
-wait $runner_pid
+$PYTHON_EXE ".."/tests/testrunner.py --local-modules "$@"
